Struct HoprKeyIdent
pub struct HoprKeyIdent<const N: usize = 4>([u8; N]);Expand description
Identifier of public keys.
Tuple Fields
0: [u8; N]Trait Implementations
impl<'de, const N: usize> Deserialize<'de> for KeyIdent<N>
impl<'de, const N: usize> Deserialize<'de> for KeyIdent<N>
fn deserialize<__D>(
__deserializer: __D,
) -> Result<KeyIdent<N>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<KeyIdent<N>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<B> KeyIdMapping<KeyIdent, OffchainPublicKey> for HoprKeyMapper<B>
impl<B> KeyIdMapping<KeyIdent, OffchainPublicKey> for HoprKeyMapper<B>
Sourcefn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
fn map_key_to_id(&self, key: &OffchainPublicKey) -> Option<HoprKeyIdent>
Maps public key to its unique identifier.
Sourcefn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
fn map_id_to_public(&self, id: &HoprKeyIdent) -> Option<OffchainPublicKey>
Maps public key identifier to the actual public key.
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
Convenience method to map a slice of public keys to IDs.
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
Convenience method to map a slice of IDs to public keys.
impl<const N: usize> Ord for KeyIdent<N>
impl<const N: usize> Ord for KeyIdent<N>
impl<const N: usize> PartialOrd for KeyIdent<N>
impl<const N: usize> PartialOrd for KeyIdent<N>
impl<const N: usize> Serialize for KeyIdent<N>
impl<const N: usize> Serialize for KeyIdent<N>
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<const N: usize> Copy for KeyIdent<N>
impl<const N: usize> Eq for KeyIdent<N>
impl<const N: usize> StructuralPartialEq for KeyIdent<N>