Struct RedeemableTicket
pub struct RedeemableTicket {
pub ticket: VerifiedTicket,
pub response: Response,
pub vrf_params: VrfParameters,
pub channel_dst: HashBase<CoreWrapper<Keccak256Core>>,
}Expand description
Represents a winning ticket that can be successfully redeemed on-chain.
Fields
ticket: VerifiedTicketVerified ticket that can be redeemed.
response: ResponseSolution to the PoR challenge in the ticket.
vrf_params: VrfParametersVRF parameters required for redeeming.
channel_dst: HashBase<CoreWrapper<Keccak256Core>>Channel domain separator used to compute the VRF parameters.
Implementations
impl RedeemableTicket
impl RedeemableTicket
pub fn verified_ticket(&self) -> &Ticket
pub fn verified_ticket(&self) -> &Ticket
Convenience method to retrieve a reference to the underlying verified [Ticket].
pub fn ticket_id(&self) -> TicketId
pub fn ticket_id(&self) -> TicketId
Gets the [TicketId] of the ticket.