Struct VerifiedTicket
pub struct VerifiedTicket {
ticket: Ticket,
hash: HashBase<CoreWrapper<Keccak256Core>>,
issuer: Address,
channel_id: HashBase<CoreWrapper<Keccak256Core>>,
}Expand description
Holds a ticket that has been already verified.
This structure guarantees that [Ticket::get_hash()] of VerifiedTicket::verified_ticket()
is always equal to VerifiedTicket::verified_hash
Fields
ticket: Tickethash: HashBase<CoreWrapper<Keccak256Core>>issuer: Addresschannel_id: HashBase<CoreWrapper<Keccak256Core>>Implementations
impl VerifiedTicket
impl VerifiedTicket
pub fn win_prob(&self) -> WinningProbability
pub fn win_prob(&self) -> WinningProbability
Returns the verified encoded winning probability of the ticket
pub fn is_winning(
&self,
response: &Response,
chain_keypair: &ChainKeypair,
domain_separator: &HashBase<CoreWrapper<Keccak256Core>>,
) -> bool
pub fn is_winning( &self, response: &Response, chain_keypair: &ChainKeypair, domain_separator: &HashBase<CoreWrapper<Keccak256Core>>, ) -> bool
Checks if this ticket is considered a win. Requires access to the private key to compute the VRF values.
Computes the ticket’s luck value and compares it against the ticket’s probability. If luck <= probability, the ticket is considered a win.
Ticket luck value
This ticket’s luck value is the first 7 bytes of Keccak256 hash
where the input is the concatenation of ticket’s hash, VRF’s encoded v value,
PoR response and the ticket’s signature.
Winning probability
Each ticket specifies a probability, given as an integer in
[0, 2^56-1] where 0 -> 0% and 2^56 - 1 -> 100% win
probability. If the ticket’s luck value is greater than
the stated probability, it is considered a winning ticket.
pub fn verified_ticket(&self) -> &Ticket
pub fn verified_ticket(&self) -> &Ticket
Ticket with already verified signature.
pub fn verified_hash(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
pub fn verified_hash(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
Fixed ticket hash that is guaranteed to be equal to
[Ticket::get_hash] of VerifiedTicket::verified_ticket.
pub fn verified_issuer(&self) -> &Address
pub fn verified_issuer(&self) -> &Address
Verified issuer of the ticket.
The returned address is guaranteed to be equal to the signer
recovered from the VerifiedTicket::verified_ticket’s signature.
pub fn channel_id(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
pub fn channel_id(&self) -> &HashBase<CoreWrapper<Keccak256Core>>
Channel ID of the ticket.
The ticket is guaranteed to belong to the channel with the returned ChannelId.
pub fn verified_signature(&self) -> &ChainSignature<NativeEcdsaSigningEngine>
pub fn verified_signature(&self) -> &ChainSignature<NativeEcdsaSigningEngine>
Shorthand to retrieve reference to the verified ticket signature
pub fn leak(self) -> Ticket
pub fn leak(self) -> Ticket
Deconstructs self back into the unverified [Ticket].
pub fn into_unacknowledged(self, own_key: HalfKey) -> UnacknowledgedTicket
pub fn into_unacknowledged(self, own_key: HalfKey) -> UnacknowledgedTicket
Creates a new unacknowledged ticket from the VerifiedTicket,
given our own part of the PoR challenge.
pub fn into_acknowledged(self, response: Response) -> AcknowledgedTicket
pub fn into_acknowledged(self, response: Response) -> AcknowledgedTicket
Shorthand to acknowledge the ticket if the matching response is already known.